pub type Wrapped<C> = Mapped<C, IdentityMapper<C>>;Expand description
Sometimes it is useful to wrap an existing combinator within a Mapped combinator so that the SpecFrom trait works better
Aliased Type
struct Wrapped<C> {
pub inner: C,
pub mapper: IdentityMapper<C>,
}Fields
inner: CThe inner combinator.
mapper: IdentityMapper<C>The isomorphism.